==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/sv/Filter.js <==
({
	"clearFilterDialogTitle": "Rensa filter",
	"filterDefDialogTitle": "Filter",
	"ruleTitleTemplate": "Regel ${0}",
	
	"conditionEqual": "lika med",
	"conditionNotEqual": "inte lika med",
	"conditionLess": "är mindre än",
	"conditionLessEqual": "mindre eller lika med",
	"conditionLarger": "är större än",
	"conditionLargerEqual": "större än eller lika med",
	"conditionContains": "innehåller",
	"conditionIs": "är",
	"conditionStartsWith": "börjar med",
	"conditionEndWith": "slutar med",
	"conditionNotContain": "innehåller inte",
	"conditionIsNot": "är inte",
	"conditionNotStartWith": "börjar inte med",
	"conditionNotEndWith": "slutar inte med",
	"conditionBefore": "före",
	"conditionAfter": "efter",
	"conditionRange": "intervall",
	"conditionIsEmpty": "är tom",
	
	"all": "alla",
	"any": "någon",
	"relationAll": "alla regler",
	"waiRelAll": "Matcha alla följande regler:",
	"relationAny": "någon regel",
	"waiRelAny": "Matcha någon av följande regler:",
	"relationMsgFront": "Matcha",
	"relationMsgTail": "",
	"and": "och",
	"or": "eller",
	
	"addRuleButton": "Lägg till regel",
	"waiAddRuleButton": "Lägg till en ny regel",
	"removeRuleButton": "Ta bort regel",
	"waiRemoveRuleButtonTemplate": "Ta bort regel ${0}",
	
	"cancelButton": "Avbryt",
	"waiCancelButton": "Avbryt dialogen",
	"clearButton": "Rensa",
	"waiClearButton": "Rensa filtret",
	"filterButton": "Filtrera",
	"waiFilterButton": "Filtrera",
	
	"columnSelectLabel": "Kolumn",
	"waiColumnSelectTemplate": "Kolumn för regel ${0}",
	"conditionSelectLabel": "Villkor",
	"waiConditionSelectTemplate": "Villkor för regel ${0}",
	"valueBoxLabel": "Värde",
	"waiValueBoxTemplate": "Ange värde för filtrering efter regeln ${0}",
	
	"rangeTo": "till",
	"rangeTemplate": "från ${0} till ${1}",
	
	"statusTipHeaderColumn": "Kolumn",
	"statusTipHeaderCondition": "Regler",
	"statusTipTitle": "Filterfält",
	"statusTipMsg": "Klicka på filterfältet om du vill filtrera värden i ${0}.",
	"anycolumn": "alla kolumner",
	"statusTipTitleNoFilter": "Filterfält",
	"statusTipTitleHasFilter": "Filter",
	"statusTipRelPre": "Matcha",
	"statusTipRelPost": "regler.",
	
	"defaultItemsName": "objekt",
	"filterBarMsgHasFilterTemplate": "${0} av ${1} ${2} visas.",
	"filterBarMsgNoFilterTemplate": "Inget filter tillämpat",
	
	"filterBarDefButton": "Definiera filter",
	"waiFilterBarDefButton": "Filtrera tabellen",
	"a11yFilterBarDefButton": "Filter...",
	"filterBarClearButton": "Rensa filter",
	"waiFilterBarClearButton": "Rensa filtret",
	"closeFilterBarBtn": "Stäng filterfält",
	
	"clearFilterMsg": "Tar bort filtret och visar alla tillgängliga poster.",
	"anyColumnOption": "Alla kolumner",
	
	"trueLabel": "Sant",
	"falseLabel": "Falskt"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/sv/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "Rensa filter",
	"filterDefDialogTitle": "Filter",
	"ruleTitleTemplate": "Regel ${0}",
	
	"conditionEqual": "lika med",
	"conditionNotEqual": "inte lika med",
	"conditionLess": "är mindre än",
	"conditionLessEqual": "mindre eller lika med",
	"conditionLarger": "är större än",
	"conditionLargerEqual": "större än eller lika med",
	"conditionContains": "innehåller",
	"conditionIs": "är",
	"conditionStartsWith": "börjar med",
	"conditionEndWith": "slutar med",
	"conditionNotContain": "innehåller inte",
	"conditionIsNot": "är inte",
	"conditionNotStartWith": "börjar inte med",
	"conditionNotEndWith": "slutar inte med",
	"conditionBefore": "före",
	"conditionAfter": "efter",
	"conditionRange": "intervall",
	"conditionIsEmpty": "är tom",
	
	"all": "alla",
	"any": "någon",
	"relationAll": "alla regler",
	"waiRelAll": "Matcha alla följande regler:",
	"relationAny": "någon regel",
	"waiRelAny": "Matcha någon av följande regler:",
	"relationMsgFront": "Matcha",
	"relationMsgTail": "",
	"and": "och",
	"or": "eller",
	
	"addRuleButton": "Lägg till regel",
	"waiAddRuleButton": "Lägg till en ny regel",
	"removeRuleButton": "Ta bort regel",
	"waiRemoveRuleButtonTemplate": "Ta bort regel ${0}",
	
	"cancelButton": "Avbryt",
	"waiCancelButton": "Avbryt dialogen",
	"clearButton": "Rensa",
	"waiClearButton": "Rensa filtret",
	"filterButton": "Filtrera",
	"waiFilterButton": "Filtrera",
	
	"columnSelectLabel": "Kolumn",
	"waiColumnSelectTemplate": "Kolumn för regel ${0}",
	"conditionSelectLabel": "Villkor",
	"waiConditionSelectTemplate": "Villkor för regel ${0}",
	"valueBoxLabel": "Värde",
	"waiValueBoxTemplate": "Ange värde för filtrering efter regeln ${0}",
	
	"rangeTo": "till",
	"rangeTemplate": "från ${0} till ${1}",
	
	"statusTipHeaderColumn": "Kolumn",
	"statusTipHeaderCondition": "Regler",
	"statusTipTitle": "Filterfält",
	"statusTipMsg": "Klicka på filterfältet om du vill filtrera värden i ${0}.",
	"anycolumn": "alla kolumner",
	"statusTipTitleNoFilter": "Filterfält",
	"statusTipTitleHasFilter": "Filter",
	"statusTipRelAny": "Matcha någon regel.",
	"statusTipRelAll": "Matcha alla regler.",
	
	"defaultItemsName": "objekt",
	"filterBarMsgHasFilterTemplate": "${0} av ${1} ${2} visas.",
	"filterBarMsgNoFilterTemplate": "Inget filter tillämpat",
	
	"filterBarDefButton": "Definiera filter",
	"waiFilterBarDefButton": "Filtrera tabellen",
	"a11yFilterBarDefButton": "Filter...",
	"filterBarClearButton": "Rensa filter",
	"waiFilterBarClearButton": "Rensa filtret",
	"closeFilterBarBtn": "Stäng filterfält",
	
	"clearFilterMsg": "Tar bort filtret och visar alla tillgängliga poster.",
	"anyColumnOption": "Alla kolumner",
	
	"trueLabel": "Sant",
	"falseLabel": "Falskt"
})
//end v1.x content
);
